@@ -27,6 +27,8 @@ def pad_sequence(input_ids_list: List[np.ndarray], padding_value: int = 0):
 class OnnxModelEvaluation(SimilarityEvaluation):
     """Using ONNX model to evaluate sentences pair similarity.
 
+    This evaluator use the ONNX model to evaluate the similarity of two sentences.
+
     :param model: model name of OnnxModelEvaluation. Default is 'GPTCache/albert-duplicate-onnx'.
     :type model: str
 
@@ -69,7 +71,7 @@ class OnnxModelEvaluation(SimilarityEvaluation):
         try:
             src_question = src_dict["question"]
             cache_question = cache_dict["question"]
-            if src_question == cache_question:
+            if src_question.lower() == cache_question.lower():
                 return 1
             return self.inference(src_question, [cache_question])
         except Exception:  # pylint: disable=W0703
