@@ -1,5 +1,8 @@
 import subprocess
 
+from gptcache.utils.error import PipInstallError
+from gptcache.utils.log import gptcache_log
+
 
 def prompt_install(package: str, warn: bool = False):  # pragma: no cover
     """
@@ -10,6 +13,6 @@ def prompt_install(package: str, warn: bool = False):  # pragma: no cover
         if warn and input(f"Install {package}? Y/n: ") != "Y":
             raise ModuleNotFoundError(f"No module named {package}")
         subprocess.check_call(cmd, shell=True)
-        print(f"{package} installed successfully!")
-    except subprocess.CalledProcessError:
-        print(f"Ran into error installing {package}.")
+        gptcache_log.info("%s installed successfully!", package)
+    except subprocess.CalledProcessError as e:
+        raise PipInstallError(package) from e
